==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/HorizontalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var HorizontalAnchoredCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HorizontalAnchoredCategorySeriesDescriptionMetadata, _super);
    function HorizontalAnchoredCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalAnchoredCategorySeriesDescriptionMetadata.b = function (a) {
        if (HorizontalAnchoredCategorySeriesDescriptionMetadata.a == null) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        if (a.g(HorizontalAnchoredCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    HorizontalAnchoredCategorySeriesDescriptionMetadata.c = function (a) {
        AnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    HorizontalAnchoredCategorySeriesDescriptionMetadata.d = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.b(a);
        a.t("HorizontalAnchoredCategorySeries", HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    HorizontalAnchoredCategorySeriesDescriptionMetadata.$t = markType(HorizontalAnchoredCategorySeriesDescriptionMetadata, 'HorizontalAnchoredCategorySeriesDescriptionMetadata');
    HorizontalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return HorizontalAnchoredCategorySeriesDescriptionMetadata;
}(Base));
export { HorizontalAnchoredCategorySeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/HorizontalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var HorizontalAnchoredCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HorizontalAnchoredCategorySeriesDescriptionMetadata, _super);
    function HorizontalAnchoredCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HorizontalAnchoredCategorySeriesDescriptionMetadata.b = function (a) {
        if (HorizontalAnchoredCategorySeriesDescriptionMetadata.a == null) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        if (a.j(HorizontalAnchoredCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    HorizontalAnchoredCategorySeriesDescriptionMetadata.c = function (a) {
        AnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    HorizontalAnchoredCategorySeriesDescriptionMetadata.d = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.b(a);
        a.z("HorizontalAnchoredCategorySeries", HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    HorizontalAnchoredCategorySeriesDescriptionMetadata.$t = markType(HorizontalAnchoredCategorySeriesDescriptionMetadata, 'HorizontalAnchoredCategorySeriesDescriptionMetadata');
    HorizontalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return HorizontalAnchoredCategorySeriesDescriptionMetadata;
}(Base));
export { HorizontalAnchoredCategorySeriesDescriptionMetadata };
